azure_credential
:   The credential type (either `azure-cli` or `managed-identity`) to use when
    authenticating with Azure. If this is omitted then the default Azure
    authentication flow will be used.

    Scope: Global/Server/Model.
